\name{A1}
\title{Ratio of First and Zeroth Order Bessel Functions}
\alias{A1}

\description{Evaluates the first and zeroth order Bessel functions of the first kind at a specified non-negative real number, and returns the ratio.} 

\usage{
A1(kappa)
}

\arguments{
\item{kappa}{non-negative numeric value at which to evaluate the Bessel functions.}
}

\value{
If I1(kappa) is the first order Bessel function and I0(kappa) is the zeroth order Bessel function, then A1(kappa) returns I1(kappa)/I0(kappa).
}

\details{
The function uses \code{\link{besselI}}.
}

\author{Claudio Agostinelli}

\seealso{
 \code{\link{besselI}}, \code{\link{A1inv}}.
}


\keyword{math}

\eof
\name{A1inv}
\title{Inverse of A1}
\alias{A1inv}

\description{
Inverse function of the ratio of the first and zeroth order Bessel functions of the first kind.  This function is used to compute the maximum likelihood estimate of the concentration parameter of a von Mises distribution.
}

\usage{
A1inv(x)
}

\arguments{
\item{x}{numeric value in the interval between 0 and 1.}
}

\value{
Returns the value k, such that A1inv(x) = k, i.e. A1(k) = x.
}

\details{
A1inv(0) = 0 and A1inv(1) = Inf.  This function is useful in estimating
the concentration parameter of data from a von Mises distribution. Our
function use the results in Best and Fisher (1981). Tables use tabulated
values by Gumbel, Greenwood and Durand (1953).
}

\author{Claudio Agostinelli}

\references{
     BEST, D.J. and FISHER, N.I. 1981. The bias of the maximum 
       likelihood estimators for the von Mises-Fisher concentration 
       parameters. Communications in Statistics, 10, 493-502.

     GUMBEL, E.J., GREENWOOD, J.A. AND DURAND, D.  1953.  The circular 
       normal distribution: theory and tables.  J. Amer. Statis. Assoc., 
       48, 131-152.
}

\seealso{
\code{\link{mle.vonmises}}, \code{\link{A1}}, \code{\link{besselI}}.
}

\examples{
#Generate data from a von Mises distribution
data <- rvonmises(n=50, mu=pi, kappa=4)
#Estimate the concentration parameter
s <- sum(sin(data))
c <- sum(cos(data))
mean.dir <- atan(s, c)
kappa <- A1inv(mean(cos(data - mean.dir)))
}

\keyword{math}

\eof
\name{I.0}
\title{Zeroth Order Bessel Function of the First Kind}
\alias{I.0}

\description{
An alias of \code{besselI(x, nu=0)}.
}

\usage{
I.0(x)
}

\arguments{
\item{x}{non-negative numerical value at which to evaluate the Bessel function.}
}

\value{
Returns the zeroth order Bessel function of the first kind evaluated at a specified real number.
}

\seealso{
\code{\link{besselI}}.
}

\keyword{math}


\eof
\name{I.1}
\title{First Order Bessel Function of the First Kind}
\alias{I.1}

\description{
An alias of \code{besselI(x, nu=1)}.
}

\usage{
I.1(x)
}

\arguments{
\item{x}{non-negative numerical value at which to evaluate the Bessel function.}
}

\value{
Returns the first order Bessel function of the first kind, evaluated at a specified real number.
}


\seealso{
\code{\link{besselI}}. 
}

\keyword{math}


\eof
\name{I.p}
\title{P-th Order Bessel Function of the First Kind}
\alias{I.p}

\description{
An alias of \code{besselI(x, nu=p)}.
}

\usage{
I.p(p, x)
}

\arguments{
\item{p}{positive integer order of the Bessel function.}
\item{x}{non-negative numerical value at which to evaluate the Bessel function.}
}

\value{
Returns the p-th order Bessel function of the first kind, evaluated at a specified real number.
}


\seealso{
\code{\link{besselI}}.
}

\keyword{math}


\eof
\name{as.data.frame.circular}
\title{as.data.frame.circular}
\alias{as.data.frame.circular}

\description{
  This function is a method of \code{\link{as.data.frame}} for a circular object.
}
\usage{
as.data.frame.circular(x, row.names = NULL, optional = FALSE)
}
\arguments{
  \item{x}{object of class \code{\link{circular}}.}
  \item{row.names}{\code{NULL} or a character vector giving the row
    names for the data frame. Missing values are not allowed.}
    \item{optional}{logical; if \code{TRUE} setting row names is
      optional.}
}

\author{Claudio Agostinelli}

\keyword{classes}
\keyword{methods}

\eof
\name{axis.circular}
\title{Add Axis to a Circular Plot}
\alias{axis.circular}

\description{
  Add axis to a plot of circular data points on the current graphics
  device.
}

\usage{
axis.circular(at, labels, units = c("radians", "degrees"),
     template=c("none", "geographics"),
     modulo = c("asis", "2pi", "pi"), zero=0,
     rotation = c("counter", "clock"),
     tick=TRUE, lty, lwd, cex, col, font, tcl=0.025, tcl.text=0.125, digits=2)
}

\arguments{
\item{at}{the points at which tick-marks are to be drawn. If missing the
tick-marks are placed to 0, pi/2, pi and 3pi/2 radians.}
\item{labels}{a vector of character strings to be placed at the
  tickpoints. If missing the labels are choosen according to
  \code{units} and \code{template} arguments.}
\item{units}{either \code{radians} or \code{degrees}.}
\item{template}{either \code{none} or \code{geographics}.}
\item{modulo}{either \code{asis} or \code{2pi} or \code{pi}.}
\item{zero}{the zero of the plot (in radians).}
\item{rotation}{the rotation of the plot.}
\item{tick}{logical: if \code{TRUE} ticks are plotted at tick-marks.}
\item{lty, lwd}{line type, width for the tick marks. If missing means to
  use `par("lty")' and `par("lwd")'.}
\item{cex}{a numerical value giving the amount by which plotting text and symbols should be scaled relative to the default.}
\item{col}{color for the the tick marks. If missing means to use `par("col.axis")'. }
\item{font}{font for text. If missing means to use `par("font.axis")'.}
\item{tcl}{The length of tick marks.}
\item{tcl.text}{The position of the axis labels.}
\item{digits}{number of digits used to print axis values.}
}

\author{Claudio Agostinelli}

\seealso{
\code{\link{plot.circular}} and \code{\link{ticks.circular}}.
}

\examples{
data.vm <- rvonmises(n=100, mu=0, kappa=3) 
plot(data.vm, axes=FALSE, ticks=FALSE)
axis.circular(at=seq(0, 11/6*pi, pi/6), labels=c("0",
expression(frac(pi,6)), expression(paste(frac(1,3), pi)),
expression(frac(pi,2)), expression(paste(frac(2,3), pi)),
expression(paste(frac(5,6), pi)), expression(pi),
expression(paste(frac(7,6), pi)), expression(paste(frac(4,3), pi)),
expression(paste(frac(3,2), pi)), expression(paste(frac(5,3), pi)),
expression(paste(frac(11,6), pi))))
}

\keyword{hplot}

\eof
\name{Cardioid}
\title{Cardioid Density Function}
\alias{dcardioid}
\alias{rcardioid}

\description{
Density and random generation for the Cardioid circular distribution.  
}

\usage{
dcardioid(x, mu = 0, rho = 0)
rcardioid(n, mu = 0, rho = 0, units = c("radians", "degrees"), \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class \code{\link{circular}}.}
\item{n}{number of observations.}  
\item{mu}{mean direction of the distribution.}
\item{rho}{concentration parameter of the distribution. Absolute value of \code{rho} must be less than 0.5.}
\item{units}{units of measure desired.}
\item{\dots}{parameters passed to \code{\link{circular}}.}
}

\value{
\code{dcardioid} gives the density and \code{rcardioid} generates random deviates.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 2.2.2, World Scientific Press, Singapore.
}

\keyword{distribution}

\eof
\name{change.point}
\title{Change Point Test}
\alias{change.point}

\description{
Tests for a change in mean direction, concentration, or both, given a set of directional data points. 
}

\usage{
change.point(x)
}

\arguments{
\item{x}{a vector. The object is coerced to class \code{\link{circular}}.}
}

\value{
Returns a list with variables n, rho, rmax, k.r, rave, tmax, k.t, and
tave. The first of these is the sample size, followed by the overall
mean resultant length. Both of these are needed to enter any of the
tables or nomograms (see under Details). The other values represent the change point test statistics.  While rmax and rave test for a change in mean direction (with unknown concentration), tmax and tave are useful in the context of testing more generally, for a change in mean direction and/or concentration. k.r and k.t are the observation numbers for which rmax and tmax attain their maximum value and indicate the observation at which the change is most likely to have occurred, when the tables or nomograms indicate significance. 
}

\details{
In either context, the user can choose which statistic (max or ave) to use, and then consult the appropriate table provided in the book referenced below. The critical values for these 4 statistics are to be found in Table 11.3 (or Figure 11.3) for rmax, Table 11.4 (or Figure 11.4) for rave, Figure 11.5 for tmax and Figure 11.6 for tave.
}

\author{Claudio Agostinelli and Ulric Lund}

\seealso{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Chapter 11, World Scientific Press, Singapore.  
}

\keyword{htest}

\eof
\name{Circular}
\alias{circular}
\alias{as.circular}
\alias{is.circular}
\alias{print.circular}
\title{Create Objects of class circular for Circular data.}
\description{
The function \code{circular} is used to create circular objects. \code{as.circular} and \code{is.circular} coerce an object to a circular and
  test whether an object is a circular data.
}
\usage{
circular(x, type = c("angles", "directions"), units = c("radians", "degrees"), template = c("none", "geographics"), modulo = c("asis", "2pi", "pi"), zero = 0, rotation = c("counter", "clock"), names)
as.circular(x, ...)
is.circular(x)
\method{print}{circular}(x, info=TRUE, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{a vector or a matrix.}
  \item{type}{the type of measures (Not Used Yet).}
  \item{units}{units of the measures.}
  \item{template}{how the data should be plotted (Until now only
    'geographics' style is available).}
  \item{modulo}{if we need to reduce the measures to modulo.}
  \item{zero}{the zero of the axes (in radians).}
  \item{rotation}{the orientation of the axes.}
  \item{names}{names of the data.}
  \item{info}{if \code{TRUE} information on the properties of the data
    are printed.}
  \item{...}{parameters passed to \code{circular} for \code{as.circular}
    and to \code{print.default} for \code{print.circular}.}
}

\value{
an object of class \code{\link{circular}}
}

\author{Claudio Agostinelli}

\examples{
x <- circular(c(pi, pi/3, pi/4))
print(x)
is.circular(x)
}

\keyword{misc}

\eof
\name{circularp}
\alias{circularp}
\alias{circularp<-}

\title{Attributes for a Circular Object}
\description{
`circularp' returns the `circularp' attribute (or `NULL').  `circularp<-' sets the `circularp' attribute.
}
\usage{
circularp(x)
circularp(x) <- value
}

\arguments{
  \item{x}{a vector or a matrix of circular data.}
  \item{value}{a vector of length 6.}
}

\details{
     The \code{circularp} attribute is a list of five elements: type, units,
     template, modulo, zero and rotation; see \code{\link{circular}} for
     their meaning.

     Assignments are checked for consistency.    

     Assigning \code{NULL} removes the \code{circularp} attribute
     and any \code{"circular"} class of \code{x}.
}
\author{Claudio Agostinelli}

\seealso{\code{\link{circular}}}

\keyword{misc }

\eof
\name{conversion.circular}
\alias{conversion.circular}
\title{Unit of Measure Conversion for Circular Data}
\description{
Unit of Measure Conversion for Circular Data
}
\usage{
conversion.circular(x, units = c("radians", "degrees"))
}

\arguments{
  \item{x}{an object of class \code{\link{circular}}.}
  \item{units}{unit of the transformed data.}
}

}
\value{
  an object of class \code{\link{circular}} with the specified unit of
  measure.
}

\author{Claudio Agostinelli}

\seealso{
\code{\link{deg}} and \code{\link{rad}}
}

\keyword{misc}

\eof
\name{cor.circular}
\title{Correlation Coefficient for Angular Variables}
\alias{cor.circular}

\description{
Computes a circular version of the Pearson's product moment correlation, and performs a significance test if requested. 
}

\usage{
cor.circular(x, y=NULL, test=FALSE)
}

\arguments{
\item{x}{vector or matrix of circular data.}
\item{y}{vector or matrix of circular data.}
\item{test}{if \code{test == TRUE}, then a significance test for the correlation coefficient is computed.}
}

\value{
Returns a vector or a matrix of a circular version of the Pearson's
product moment correlation, if \code{test == TRUE} then a list is
reported with statistic and p.value, the test statistic and p-value respectively, for testing significance of the correlation coefficient.
}

\details{
The correlation coefficient is computed like Pearson's product moment correlation for two linear variables X and Y.  In the computational formula,  however, (xi - xbar) and (yi - ybar) are replaced by sin(xi - xbar) and sin(yi - ybar), where xbar and ybar in the second two expressions are the mean directions of the samples.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 8.2, World Scientific Press, Singapore.

Jammalamadaka, S. and Sarma, Y. (1988).  A correlation coefficient for angular variables.  Statistical Theory and Data Analysis 2. North Holland:  New York.
}

\examples{
# Generate two circular data sets, and compute their correlation.
x <- rvonmises(n=50, mu=0, kappa=3)
y <- x + rvonmises(n=50, mu=pi, kappa=10)
cor.circular(x, y, test=TRUE)
}

\keyword{univar}

\eof
\name{deg}    
\title{Degrees}
\alias{deg}

\description{
Converts radians to degrees. 
}

\usage{
deg(x)
}

\arguments{
\item{x}{vector or matrix of radian measurements.}
}

\value{
Returns a vector or matrix of degree measurements corresponding to the
data in radians.
}

\details{This function is available for compatibility with the CircStats
  package; please use \code{\link{conversion.circular}}.}

\author{Claudio Agostinelli and Ulric Lund}

\seealso{
  \code{\link{conversion.circular}} and \code{\link{rad}}
}

\keyword{math}

\eof
\name{density}
\title{Kernel Density Estimation}
\alias{density}
\alias{density.default}

\description{
  The function density computes kernel density estimates with the given kernel and bandwidth.
  The \code{density} function from the \pkg{base} is replace by a new
\code{method}. \code{density.default} is copied from the original function
\code{\link[base]{density}}. The behavior would be the same for objects which are not
from \code{\link{class}} \code{\link{circular}} (where the function \code{\link{density.circular}} is called).
}
 
\usage{
density(x, \dots)
\method{density}{default}(x, bw = "nrd0", adjust = 1, kernel = c("gaussian",
    "epanechnikov", "rectangular", "triangular", "biweight",
    "cosine", "optcosine"), window = kernel, width, give.Rkern = FALSE,
    n = 512, from, to, cut = 3, na.rm = FALSE, \dots)
}

\arguments{
  \item{x}{the data from which the estimate is to be computed.}
 
  \item{bw}{the smoothing bandwidth to be used.  The kernels are scaled
    such that this is the standard deviation of the smoothing kernel.
    (Note this differs from the reference books cited below, and from S-PLUS.)
 
    \code{bw} can also be a character string giving a rule to choose the
    bandwidth.  See \code{\link{bw.nrd}}.
   
    The specified (or computed) value of \code{bw} is multiplied by
    \code{adjust}.
  }
  \item{adjust}{the bandwidth used is actually \code{adjust*bw}.
    This makes it easy to specify values like \dQuote{half the default}
    bandwidth.}
                                                                                
  \item{kernel, window}{a character string giving the smoothing kernel
    to be used. This must be one of \code{"gaussian"},
    \code{"rectangular"}, \code{"triangular"}, \code{"epanechnikov"},
    \code{"biweight"}, \code{"cosine"} or \code{"optcosine"}, with default
    \code{"gaussian"}, and may be abbreviated to a unique prefix (single
    letter).
                                                                                
    \code{"cosine"} is smoother than \code{"optcosine"}, which is the
    usual \dQuote{cosine} kernel in the literature and almost MSE-efficient.
    However, \code{"cosine"} is the version used by S.
  }
                                                                                
  \item{width}{this exists for compatibility with S; if given, and
    \code{bw} is not, will set \code{bw} to \code{width} if this is a
    character string, or to a kernel-dependent multiple of \code{width}
    if this is numeric.}
                                                                                
  \item{give.Rkern}{logical; if true, \emph{no} density is estimated, and
    the \dQuote{canonical bandwidth} of the chosen \code{kernel} is returned
    instead.}
                                                                                
  \item{n}{the number of equally spaced points at which the density
    is to be estimated.  When \code{n > 512}, it is rounded up to the next
    power of 2 for efficiency reasons (\code{\link{fft}}).}
                                                                                
  \item{from,to}{the left and right-most points of the grid at which the
    density is to be estimated.}
                                                                                
  \item{cut}{by default, the values of \code{left} and \code{right} are
    \code{cut} bandwidths beyond the extremes of the data. This allows the
    estimated density to drop to approximately zero at the extremes.}
                                                                                
  \item{na.rm}{logical; if \code{TRUE}, missing values are removed
    from \code{x}. If \code{FALSE} any missing values cause an error.}

  \item{\dots}{further arguments passed to or from other methods.}  
}


\details{
  The algorithm used in \code{density.default} disperses the mass of the
  empirical distribution function over a regular grid of at least 512
  points and then uses the fast Fourier transform to convolve this
  approximation with a discretized version of the kernel and then uses
  linear approximation to evaluate the density at the specified points.
                                                                                
  The statistical properties of a kernel are determined by
  \eqn{\sigma^2_K = \int t^2 K(t) dt}{sig^2 (K) = int(t^2 K(t) dt)}
  which is always \eqn{= 1} for our kernels (and hence the bandwidth
  \code{bw} is the standard deviation of the kernel) and
  \eqn{R(K) = \int K^2(t) dt}{R(K) = int(K^2(t) dt)}.\cr
  MSE-equivalent bandwidths (for different kernels) are proportional to
  \eqn{\sigma_K R(K)}{sig(K) R(K)} which is scale invariant and for our
  kernels equal to \eqn{R(K)}.  This value is returned when
  \code{give.Rkern = TRUE}.  See the examples for using exact equivalent
  bandwidths.
                                                                                
  Infinite values in \code{x} are assumed to correspond to a point mass at
  \code{+/-Inf} and the density estimate is of the sub-density on
  \code{(-Inf, +Inf)}.
}

\value{
  If \code{give.Rkern} is true, the number \eqn{R(K)}, otherwise
  an object with class \code{"density"} whose
  underlying structure is a list containing the following components.
  \item{x}{the \code{n} coordinates of the points where the density is
    estimated.}
  \item{y}{the estimated density values.}
  \item{bw}{the bandwidth used.}
  \item{N}{the sample size after elimination of missing values.}
  \item{call}{the call which produced the result.}
  \item{data.name}{the deparsed name of the \code{x} argument.}
  \item{has.na}{logical, for compatibility (always FALSE).}
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth \& Brooks/Cole (for S version).
                                                                                
  Scott, D. W. (1992)
  \emph{Multivariate Density Estimation. Theory, Practice and Visualization}.
  New York: Wiley.
                                                                                
  Sheather, S. J. and Jones M. C. (1991)
  A reliable data-based bandwidth selection method for kernel density
  estimation.
  \emph{J. Roy. Statist. Soc.} \bold{B}, 683--690.
                                                                                
  Silverman, B. W. (1986)
  \emph{Density Estimation}.
  London: Chapman and Hall.
                                                                                
  Venables, W. N. and Ripley, B. D. (1999)
  \emph{Modern Applied Statistics with S-PLUS}.
  New York: Springer.
}


  
\seealso{
\code{\link[base]{density}}, \code{\link{density.circular}}, \code{\link{bw.nrd}},
  \code{\link{plot.density}}, \code{\link{hist}}.
}

\examples{
plot(density(c(-20,rep(0,98),20)), xlim = c(-4,4))# IQR = 0

# The Old Faithful geyser data
data(faithful)
d <- density(faithful$eruptions, bw = "sj")
d
plot(d)

plot(d, type = "n")
polygon(d, col = "wheat")

## Missing values:
x <- xx <- faithful$eruptions
x[i.out <- sample(length(x), 10)] <- NA
doR <- density(x, bw = 0.15, na.rm = TRUE)
lines(doR, col = "blue")
points(xx[i.out], rep(0.01, 10))


(kernels <- eval(formals(density.default)$kernel))

## show the kernels in the R parametrization
plot (density(0, bw = 1), xlab = "",
      main="R's density() kernels with bw = 1")
for(i in 2:length(kernels))
   lines(density(0, bw = 1, kern =  kernels[i]), col = i)
legend(1.5,.4, legend = kernels, col = seq(kernels),
       lty = 1, cex = .8, y.int = 1)

## show the kernels in the S parametrization
plot(density(0, from=-1.2, to=1.2, width=2, kern="gaussian"), type="l",
     ylim = c(0, 1), xlab="", main="R's density() kernels with width = 1")
for(i in 2:length(kernels))
   lines(density(0, width=2, kern =  kernels[i]), col = i)
legend(0.6, 1.0, legend = kernels, col = seq(kernels), lty = 1)

(RKs <- cbind(sapply(kernels, function(k)density(kern = k, give.Rkern = TRUE))))
100*round(RKs["epanechnikov",]/RKs, 4) ## Efficiencies

if(interactive()) {
data(precip)
bw <- bw.SJ(precip) ## sensible automatic choice
plot(density(precip, bw = bw, n = 2^13),
     main = "same sd bandwidths, 7 different kernels")
for(i in 2:length(kernels))
   lines(density(precip, bw = bw, kern =  kernels[i], n = 2^13), col = i)

## Bandwidth Adjustment for "Exactly Equivalent Kernels"
h.f <- sapply(kernels, function(k)density(kern = k, give.Rkern = TRUE))
(h.f <- (h.f["gaussian"] / h.f)^ .2)
## -> 1, 1.01, .995, 1.007,... close to 1 => adjustment barely visible..

plot(density(precip, bw = bw, n = 2^13),
     main = "equivalent bandwidths, 7 different kernels")
for(i in 2:length(kernels))
   lines(density(precip, bw = bw, adjust = h.f[i], kern =  kernels[i],
         n = 2^13), col = i)
legend(55, 0.035, legend = kernels, col = seq(kernels), lty = 1)
}
}

\keyword{distribution}
\keyword{smooth}


\eof
\name{density.circular}
\alias{density.circular}
\alias{print.density.circular}

\title{Kernel Density Estimation for Circular Data}
\description{
  The function \code{density.circular} computes kernel density estimates
  with the given kernel and bandwidth for circular data.
}

\usage{
\method{density}{circular}(x, z, bw, adjust = 1, type = c("K", "L"),
     kernel = c("vonmises", "wrappednormal"), na.rm = FALSE, from = 0,
     to = 2 * pi, n = 512, K = 10, \dots)
\method{print}{density.circular}(x, digits = NULL, \dots)
}

\arguments{
  \item{x}{the data from which the estimate is to be computed.}
  \item{z}{the points where the density is estimated. If missing
    equally spaced points are used according to the parameters
    \code{from}, \code{to} and \code{n}.}
  \item{bw}{the smoothing bandwidth to be used. When the \code{kernel}
    is \code{vonmises} the bandwidth is equal to the concentration
    parameter.}
  \item{adjust}{the bandwidth used is actually \code{adjust*bw}. This
    makes it easy to specify values like ``half the default bandwidth''.}
  \item{type}{Not Yet Used.}
  \item{kernel}{a character string giving the smoothing kernel to be
          used. This must be one of \code{"vonmises"} or
      \code{"wrappednormal"}, that are kernels of \code{type} \code{"K"}.}
  \item{na.rm}{logical; if \code{TRUE}, missing values are removed from
    \code{x}. If \code{FALSE} any missing values cause an error.}
  \item{from, to}{the left and right-most
    points of the grid at which the density is to be estimated. }
  \item{n}{the number of equally spaced points at which the density is
          to be estimated.}
  \item{K}{number of terms to be used in approximating the density.}
  \item{digits}{integer indicating the precision to be used.}
  \item{\dots}{further arguments passed to or from other methods.}
}

\value{
  an object with class \code{"density.circular"} whose
  underlying structure is a list containing the following components.
  \item{data}{original dataset.}
  \item{x}{the \code{n} coordinates of the points where the density is
    estimated.}
  \item{y}{the estimated density values.}
  \item{bw}{the bandwidth used.}
  \item{N}{the sample size after elimination of missing values.}
  \item{call}{the call which produced the result.}
  \item{data.name}{the deparsed name of the \code{x} argument.}
  \item{has.na}{logical, for compatibility (always FALSE).}
}

\references{
Z.D. Bai and C.R. Rao and L.C. Zhao (1988). Kernel Estimators of Density
Function of Directional Data, Journal of Multivariate Analysis, 27, 24-39.

J. Klemel\"a (2000). Estimation of densities and derivatives of
densities with directioinal data, Journal of Multivariate Analysis, 73, 18-40.

V.R. Prayag and A.P. Gore (1990). Density Estimation for Randomly
Distributed Circular Objects, Metrika, 1990, 37, 63-69.

P. Hall and G.S. Watson and J. Cabrera (1987). Kernel Density Estimation
with Spherical Data, Biometrika, 74, 4, 751--762.
}

\author{Claudio Agostinelli}

\seealso{\code{\link{plot.density.circular}}
  and \code{\link{lines.density.circular}}}

\examples{
x <- rvonmises(n=100, mu=pi, kappa=2)
res25 <- density(x, bw=25)
plot(res25, points.plot=TRUE, xlim=c(-1.5,1))
res50 <- density(x, bw=25, adjust=2)
lines(res50, col=2)
}

\keyword{distribution}
\keyword{smooth}

\eof
\name{[.circular}
\title{Extract or Replace Parts of a Circular Object}
\alias{[.circular}

\description{
  Operators act on vectors and matrices to extract or
  replace subsets, methods for Circular Data.
}

\usage{
x[i]
x[i, j, \dots]
x[i, j, \dots , drop=TRUE]
}

\arguments{
  \item{x}{object from which to extract elements.}
  \item{i, j, \dots}{elements to extract or replace.}
  \item{drop}{For matrices.  If \code{TRUE} the
    result is coerced to the lowest possible dimension (see examples
    below).}
}

\author{Claudio Agostinelli}

\example{
x <- circular(matrix(rwrappednormal(n=100, mu=0), nrow=5))
dim(x)
x[1,]
x[,1]
x[,1, drop=FALSE]
}

\keyword{array}

\eof
\name{kuiper.test}
\title{Kuiper's Test}
\alias{kuiper.test}
\alias{print.kuiper.test}
\description{
Performs Kuiper's one-sample test of uniformity on the circle. 
}

\usage{
kuiper.test(x, alpha=0)
\method{print}{kuiper.test}(x, digits = 4, \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}

  \item{alpha}{significance level of the test.  Possible levels are
    0.15, 0.1, 0.05, 0.025, 0.01.  Alpha may be omitted or set to zero,
    in which case a range for the p-value of the test will be printed.}
  \item{digits}{integer indicating the precision to be used.}
  \item{\dots}{further arguments passed to or from other methods.}
}

\value{
A list with the statistic and alpha value.
}

\note{
Kuiper's one-sample test of uniformity is performed, and the results are printed to the screen.  If alpha is specified and non-zero, the test statistic is printed along with the critical value and decision.  If alpha is omitted, the test statistic is printed and a range for the p-value of the test is given.
}

\details{
Kuiper's test statistic is a rotation-invariant Kolmogorov-type test statistic.  The critical values of a modified Kuiper's test statistic are used according to the tabulation given in Stephens (1970). 
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 7.2, World Scientific Press, Singapore.

Stephens, M. (1970).  Use of the Kolmogorov-Smirnov, Cramer-von Mises and related statistics without extensive tables.  Journal of the Royal Statistical Society, B32, 115122.
}

\seealso{
\code{\link{range.circular}}, \code{\link{rao.spacing.test}},
\code{\link{rayleigh.test}} and \code{\link{watson.test}}
}

\exammples{
# Generate data from the uniform distribution on the circle.
data <- circular(runif(100, 0, 2*pi))
kuiper.test(data)
# Generate data from the von Mises distribution.
data <- rvonmises(n=100, mu=0, kappa=3)
kuiper.test(data, alpha=0.01)
}

\keyword{htest}

\eof
\name{lines.density.circular}
\alias{lines.density.circular}

\title{Add a Plot for Kernel Density Estimation for Circular Data}
\description{
   The \code{lines} add a plot for \code{density.circular} objects.
}
\usage{
\method{lines}{density.circular}(x, type = "l", zero.line = TRUE, points.plot = FALSE, points.col = 1, points.pch = 1, plot.type = c("circle", "line"), bins, shrink = 1, tcl = 0.025, ...)
}

\arguments{
  \item{x}{an object of class \code{\link{density.circular}}.}
  \item{type}{plotting parameter with useful default.}
  \item{zero.line}{logical; if \code{TRUE}, add a base line at \eqn{y =
      0}. Used when \code{plot.type} is \code{"line"}.}
  \item{points.plot}{logical; if \code{TRUE} original data are added to
    the plot.}
  \item{points.col, points.pch}{parameters used to draw the points.}
  \item{plot.type}{type of the plot.}
  \item{bins}{number of ticks to plot. }
  \item{shrink}{parameter that controls the size of the plotted circle.
  Default is 1.  Larger values shrink the circle, while smaller values
  enlarge the circle.}
\item{tcl}{length of the ticks.}
  \item{\dots}{futher parameters passed to \code{\link{lines.default}}.}
}

\value{
None.
}

\author{Claudio Agostinelli}

\seealso{\code{\link{density.circular}} and \code{\link{plot.density.circular}} }

\examples{
x <- rvonmises(n=100, mu=pi, kappa=2)
res25 <- density(x, bw=25)
plot(res25, points.plot=TRUE, xlim=c(-1.5,1))
res50 <- density(x, bw=25, adjust=2)
lines(res50, col=2)
}

\keyword{dplot}


\eof
\name{lm.circular}    
\title{Circular-Circular Regression}
\alias{lm.circular}

\description{
Fits a regression model for a circular dependent and circular independent variable.  
}

\usage{
lm.circular(y, x, order=1, level=0.05)
}

\arguments{
\item{y}{vector of data for the dependent circular variable.}
\item{x}{vector of data for the independent circular variable.}
\item{order}{order of trigonometric polynomial to be fit. Order must be an integer value.  By default, order=1.}
\item{level}{level of the test for the significance of higher order trigonometric terms.}
}

\value{
A list is returned with the following components: 

\item{call}{match.call().}
\item{rho}{square root of the average of the squares of the estimated conditional concentration parameters of y given x.}
\item{fitted}{fitted values of the model.}
\item{data}{matrix whose columns correspond to x and y.}
\item{residuals}{circular residuals of the model.}
\item{coefficients}{matrix whose entries are the estimated coefficients of the model. The first column corresponds to the coefficients of the model predicting the cosine of y, while the second column contains the estimates for the model predicting the sine of y.  The rows of the matrix correspond to the coefficients according to increasing trigonometric order.}
\item{p.values}{p-values testing whether the (order + 1) trigonometric terms are significantly different from zero.}  
\item{A.k}{is mean of the cosines of the circular residuals.}
\item{kappa}{assuming the circular residuals come from a von Mises distribution, kappa is the MLE of the concentration parameter.}
}

\details{
A trigonometric polynomial of x is fit against the cosine and sine of y.  The order of trigonometric polynomial is specified by order.  Fitted values of y are obtained by taking the inverse tangent of the predicted values of sin(y) devided by the predicted values of cos(y).  Details of the regression model can be found in Sarma and Jammalamadaka (1993).
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 8.3, World Scientific Press, Singapore.

Sarma, Y. and Jammalamadaka, S. (1993).  Circular Regression.  Statistical Science and Data Analysis, 109128.  Proceeding of the Thrid Pacific Area Statistical Conference.  VSP: Utrecht, Netherlands.
}

\examples{
# Generate a data set of dependent circular variables.
x <- circular(runif(50, 0, 2*pi))
y <- atan(0.15*cos(x) + 0.25*sin(x), 0.35*sin(x)) + rvonmises(n=50, mu=0, kappa=5)

# Fit a circular regression model.
circ.lm <- lm.circular(y, x, order=1)
# Obtain a crude plot a data and fitted regression line.
plot.default(x, y)
circ.lm$fitted[circ.lm$fitted>pi] <- circ.lm$fitted[circ.lm$fitted>pi] - 2*pi 

points.default(x[order(x)], circ.lm$fitted[order(x)], type='l')
}

\keyword{models}

\eof
\name{mean.circular}
\title{Mean Direction}
\alias{mean.circular}

\description{
Returns the mean direction of a vector of circular data. 
}
 
\usage{
\method{mean}{circular}(x, na.rm=FALSE, \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
  \item{na.rm}{logical, indicating if \code{\link{NA}}'s should be
	omitted.}
  \item{\dots}{further arguments passed to or from other methods.}
}

\value{
Returns the mean direction of the data.
}

\details{
Each observation is treated as a unit vector, or point  on the unit
circle.  The resultant vector of the observations is found, and the
direction of the resultant vector is returned. An \code{\link{NA}} is
returned if the resultant length (see \code{\link{rho.circular}}) is
less than \code{\link{.Machine}} 
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 1.3, World Scientific Press, Singapore.
}

\seealso{
\code{\link{var.circular}}, \code{\link{summary.circular}},
\code{\link{mle.vonmises}}, \code{\link{rho.circular}} and \code{\link{.Machine}}.
}

\examples{
# Compute the mean direction of a random sample of observations.
data <- circular(runif(50, 0, pi))
mean(data)
}

\keyword{univar}

\eof
\name{mixedvonmises}    
\title{Mixture of von Mises Distributions}
\alias{dmixedvonmises}
\alias{rmixedvonmises}

\description{
  Density and random generation for the mixed von Mises circular distribution.  
}

\usage{
dmixedvonmises(x, mu1, mu2, kappa1, kappa2, p)
rmixedvonmises(n, mu1, mu2, kappa1, kappa2, p, units = c("radians",
"degrees"), \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class \code{\link{circular}}.}
  \item{n}{number of observations.}
\item{mu1}{mean direction of one of the two von Mises distributions.}
\item{mu2}{mean direction of the other von Mises distribution.}
\item{kappa1}{concentration parameter of one of the two von Mises distributions.}
\item{kappa2}{concentration parameter of the other von Mises distribution.}
\item{p}{mixing proportion.}
\item{units}{units of measure desired.}
\item{\dots}{parameters passed to \code{\link{circular}}.}
}

\value{
\code{dmixedvonmises} gives the density and \code{rmixedvonmises} generates random deviates.
}

\author{Claudio Agostinelli and Ulric Lund}

\seealso{
\code{\link{dvonmises}} and \code{\link{rvonmises}}
}

\keyword{distribution}

\eof
\name{mle.vonmises}
\title{von Mises Maximum Likelihood Estimates}
\alias{mle.vonmises}
\alias{print.mle.vonmises}

\description{
Computes the maximum likelihood estimates for the parameters of a von Mises distribution:  the mean direction and the concentration parameter.
}

\usage{
mle.vonmises(x, mu, kappa, bias=FALSE)
\method{print}{mle.vonmises}(x,
    digits = max(3, getOption("digits") - 3), \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
  \item{mu}{if missing the maximum likelihood estimate of the mean
    direction is calculated.}
  \item{kappa}{if missing the maximum likelihood estimate of the
    concentration parameter is calculated.}
  \item{bias}{logical, if \code{TRUE}, the estimate for kappa is
    computed with a bias corrected method.  Default is \code{FALSE},
    i.e. no bias correction.}
  \item{digits}{integer indicating the precision to be used.}
  \item{\dots}{further arguments passed to or from other methods.}  
}

\value{
  Returns a list with the following components:

  \item{call}{the match.call().}
  \item{mu}{the estimate of the mean direction or the value supplied.}
  \item{kappa}{the estimate of the concentration parameter or the
    value supplied}
  \item{se.mu}{the standard error for the estimate of the mean
    direction (0 if the value is supplied).}
  \item{se.kappa}{the standard error for the estimate of the
    concentration parameter (0 if the value is supplied).}
  \item{est.mu}{TRUE if the estimator is reported.}
  \item{est.kappa}{TRUE if the estimator is reported.}
}

\details{
Best and Fisher (1981) show that the MLE of kappa is seriously biased when both sample size and mean resultant length are small. They suggest a bias-corrected estimate for kappa when n < 16.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
  Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular
  Statistics, Section 4.2.1, World Scientific Press, Singapore.

  
  Best, D. and Fisher N. (1981).  The bias of the maximum likelihood
  estimators of the von Mises-Fisher concentration parameters.
  Communications in Statistics - Simulation and Computation,
  B10(5), 493502.
}

\seealso{
\code{\link{mean.circular}} and \code{\link{mle.vonmises.bootstrap.ci}}
}

\examples{
x <- rvonmises(n=50, mu=0, kappa=5)
mle.vonmises(x) # estimation of mu and kappa
mle.vonmises(x, mu=0) # estimation of kappa only
}

\keyword{htest}

\eof
\name{mle.vonmises.bootstrap.ci}
\title{Bootstrap Confidence Intervals}
\alias{mle.vonmises.bootstrap.ci}
\alias{print.mle.vonmises.bootstrap.ci}

\description{
Generates simple bootstrap confidence intervals for the parameters of a von Mises distribtution: the mean direction mu, and the concentration parameter kappa.
}


\usage{
mle.vonmises.bootstrap.ci(x, mu, bias = FALSE, alpha = 0.05, reps = 1000)
\method{print}{mle.vonmises.bootstrap.ci}(x, \dots)
}

\arguments{
  \item{x}{vector of angular measurements in radians.}
  \item{mu}{ }
\item{bias}{logical, if \code{TRUE}, the replication estimates for kappa are computed with a bias corrected method.  See \code{\link{mle.vonmises}}.  Default is \code{FALSE}, i.e. no bias correction.}
\item{alpha}{parameter determining level of confidence intervals. 1-alpha confidence intervals for \code{mu} and \code{kappa} are computed.  By default, 95\% confidence intervals are generated.}
\item{reps}{number of resampled data sets to use.  Default is 1000.}
\item{\dots}{arguments passed to \code{\link{print.default}}.}
}

\value{
  A list is returned with the following components:

  \item{mu.ci}{limits of the confidence interval for mu}
  \item{kappa.ci}{limits of the confidence interval for kappa}
  \item{mu}{estimate of mu}
  \item{kappa}{estimate of kappa}
}

\details{
Percentile confidence intervals are computed by resampling from the original data set \code{reps} times.  For each resampled data set, the MLE's of mu and kappa are computed.  The bootstrap confidence intervals are the alpha/2 and 1-alpha/2 percentiles of the \code{reps} MLE's computed for each resampled data set.
}

\author{Claudio Agostinelli and Ulric Lund}

\seealso{
\link{mle.vonmises}
}

\examples{
x <- rvonmises(n=25, mu=0, kappa=3)
x.bs <- mle.vonmises.bootstrap.ci(x, alpha=.10)
par(mfcol=c(1,2))
rose.diag(x.bs$mu, bins=30, main=expression(mu))
hist(x.bs$kappa, main=expression(kappa))
}



\keyword{htest}

\eof
\name{mle.wrappedcauchy}
\title{Wrapped Cauchy Maximum Likelihood Estimates}
\alias{mle.wrappedcauchy}
\alias{print.mle.wrappedcauchy}

\description{
Computes the maximum likelihood estimates for the parameters of a
Wrapped Cauchy distribution:  mean and concentration parameter.
}

\usage{
mle.wrappedcauchy(x, mu, rho, tol = 1e-15, max.iter = 100)
\method{print}{mle.wrappedcauchy}(x,
        digits = max(3, getOption("digits") - 3), \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
  \item{mu}{if missing the maximum likelihood estimate of the mean
    direction is calculated.}
  \item{rho}{if missing the maximum likelihood estimate of the
    concentration parameter is calculated.}
  \item{tol}{precision of the estimation.}
  \item{max.iter}{maximum number of iterations.}
   \item{digits}{integer indicating the precision to be used.}
  \item{\dots}{further arguments passed to or from other methods.}
 }

\value{
  Returns a list with the following components:

  \item{call}{the match.call().}
  \item{mu}{the estimate of the mean direction or the value supplied.}
  \item{rho}{the estimate of the concentration parameter or the
    value supplied}
  \item{convergence}{TRUE if convergence is achieved.}
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
  Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular
  Statistics, Section 4.2.1, World Scientific Press, Singapore.
}

\seealso{
\code{\link{mean.circular}}
}

\examples{
x <- rwrappednormal(n=50, mu=0, rho=0.5)
mle.wrappednormal(x) # estimation of mu and rho
mle.wrappednormal(x, mu=0) # estimation of rho only
}

\keyword{htest}

\eof
\name{mle.wrappednormal}
\title{Wrapped Normal Maximum Likelihood Estimates}
\alias{mle.wrappednormal}
\alias{print.mle.wrappednormal}

\description{
Computes the maximum likelihood estimates for the parameters of a
Wrapped Normal distribution:  mean and concentration parameter.
}

\usage{
mle.wrappednormal(x, mu, rho, sd, K, tol = 1e-05, min.sd = 0.001, min.k = 10, 
    max.iter = 100, verbose = FALSE)
\method{print}{mle.wrappednormal}(x,
        digits = max(3, getOption("digits") - 3), \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
  \item{mu}{if missing the maximum likelihood estimate of the mean
    direction is calculated.}
  \item{rho}{if missing the maximum likelihood estimate of the
    concentration parameter is calculated.}
  \item{sd}{standard deviation of the (unwrapped) normal. Used as an
    alternative parametrization.}
  \item{K}{number of terms to be used in approximating the density.}
  \item{tol}{precision of the estimation.}
  \item{min.sd}{minimum value should be reached by the search procedure
    for the standard deviation parameter.}
  \item{min.k}{minimum number of terms used in approximating the density.}
  \item{max.iter}{maximum number of iterations.}
  \item{verbose}{logical, if \code{TRUE} information on the convergence
    process are printed.}
  \item{digits}{integer indicating the precision to be used.}
  \item{\dots}{further arguments passed to or from other methods.}  
}

\value{
  Returns a list with the following components:

  \item{call}{the match.call().}
  \item{mu}{the estimate of the mean direction or the value supplied.}
  \item{rho}{the estimate of the concentration parameter or the
    value supplied}
  \item{sd}{the estimate of the standard deviation or the value supplied.}
  \item{est.mu}{TRUE if the estimator is reported.}
  \item{est.rho}{TRUE if the estimator is reported.}
  \item{convergence}{TRUE if the convergence is achieved.}
}

\author{Claudio Agostinelli}

\references{
  Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular
  Statistics, Section 4.2.1, World Scientific Press, Singapore.
}

\seealso{
\code{\link{mean.circular}}
}

\examples{
x <- rwrappednormal(n=50, mu=0, rho=0.5)
mle.wrappednormal(x) # estimation of mu and rho (and sd)
mle.wrappednormal(x, mu=0) # estimation of rho (and sd) only
}

\keyword{htest}

\eof
\name{ncfrog}
\alias{ncfrog}
\alias{ncfrog.rad}

\title{Northern Cricket Frog}

\usage{
data(ncfrog)
}

\description{
 In an experiment due to Ferguson et al. (1967) a number of northern
 cricket frogs (Acris crepitans) were collected from the mud flats of an
 abandoned stream meandering near Indianola, Mississippi, and taken to a test pen
lying to the north west of the collection point. After 30 hours of
enclosure within a dark environmental chamber, 14 of them were released and
the directions taken by these frogs recorded. 0 degrees means North.
}
\format{
\code{ncfrog} is a vector of 14 observations (in degrees).
\code{ncfrog.rad} contains the same observations in radians (pi/180).
}

\source{
 Collett, D. (1980)
 Outliers in Circular Data
 \emph{Applied Statistics}
 \bold{29}, 1, 50--57.
}

\seealso{
  Ferguson, D.E, Landreth, H.F. and McKeown, J.P. (1967)
  Sun compass orientation of the northern cricket frog, \emph{Acris crepitans}.
  \emph{Anim. Behav.},
  \bold{14}, 45--53.
}


%\examples{}

\keyword{datasets}

\eof
\name{plot.circular}
\title{Circular Data Plot}
\alias{plot.circular}

\description{
Creates a plot of circular data points on the current graphics device.  Data points are either plotted as points on the unit circle, or the range of the circle is divided into a specified number of bins, and points are stacked in the bins corresponding to the number of observations in each bin. 
}

\usage{
\method{plot}{circular}(x, pch = 16, cex = 1, stack = FALSE, axes = TRUE, sep = 0.025, 
    shrink = 1, bins, ticks = FALSE, tcl = 0.025, tcl.text = 0.125, col, tol = 0.04, 
    uin, xlim = c(-1, 1), ylim = c(-1, 1), main = NULL, digits=2, ...)
}

\arguments{
\item{x}{a vector, matrix or data.frame. The object is coerced to class \code{\link{circular}}.}
\item{pch}{point character to use.  See help on \code{\link{par}}.}
\item{cex}{point character size.  See help on par.}
\item{stack}{logical; if \code{TRUE}, points are stacked on the perimeter of the circle.  Otherwise, all points are plotted on the perimeter of the circle.  Default is \code{FALSE}.}
\item{axes}{logical; if \code{TRUE} axes are plotted according to properties of \code{x}.}
\item{sep}{constant used to specify the distance between stacked points,
  if \code{stack==TRUE} or in the case of more than one dataset.  Default is 0.025; smaller values will create smaller spaces.}
\item{shrink}{parameter that controls the size of the plotted circle.
  Default is 1.  Larger values shrink the circle, while smaller values
  enlarge the circle.}
\item{bins}{if \code{stack==TRUE}, bins is the number of arcs to partition the circle with.}
\item{ticks}{logical; if \code{TRUE} ticks are plotted according to the
  value of \code{bins}.}
\item{tcl}{length of the ticks.}
\item{tcl.text}{The position of the axis labels.}
\item{col}{color of the points. The values are recycled if needed.}
\item{tol}{proportion of white space at the margins of plot}
\item{uin}{desired values for the units per inch parameter. If of length
  1, the desired units per inch on the x axis.}
\item{xlim, ylim}{the ranges to be encompassed by the x and y
  axes. Useful for centering the plot.}
\item{main}{title of the plot.}
\item{digits}{number of digits used to print axis values.}
\item{\dots}{futher parameters passed to \code{\link{plot.default}}.}
}

\details{
When there are many closely distributed observations, stacking is
recommended. When stacking the points, if there are many points in a particular bin, it may be necessary to shrink the plot of the circle so that all points fit.  This is controlled with the parameter \code{shrink}.  Generally the parameter \code{sep} does not need adjustment, however, when shrinking the plot, or for a very large number of observations, it may be helpful.
}

\note{some codes from \code{\link{eqscplot}} in MASS is used.}

\author{Claudio Agostinelli and Ulric Lund}

\seealso{
\code{\link{axis.circular}}, \code{\link{ticks.circular}} and \code{\link{rose.diag}}.
}

\value{
a list with information on the plot: zero, rotation and next.points.
}

\examples{
# Generate 100 observations from a von Mises distribution.
# with mean direction 0 and concentration 3.
data.vm <- rvonmises(n=100, mu=0, kappa=3) 
# Plot data set. All points do not fit on plot.
plot(data.vm, stack=TRUE, bins=150) 
# Shrink the plot so that all points fit.
plot(data.vm, stack=TRUE, bins=150, shrink=1.5) 
}

\keyword{hplot}

\eof
\name{plot.density.circular}
\alias{plot.density.circular}

\title{Plot Method for Kernel Density Estimation for Circular Data}
\description{
   The \code{plot} method for \code{density.circular} objects.
}
\usage{
\method{plot}{density.circular}(x, main = NULL, xlab = NULL, ylab = "Density circular", type = "l", zero.line = TRUE, points.plot = FALSE, points.col = 1, points.pch = 1, plot.type = c("circle", "line"), axes = TRUE, ticks = TRUE, bins, shrink = 1, tcl = 0.025, tol = 0.04, uin, xlim = c(-1, 1), ylim = c(-1, 1), ...)
}

\arguments{
  \item{x}{an object of class \code{\link{density.circular}}.}
  \item{main, xlab, ylab, type}{plotting parameters with useful defaults.}
  \item{zero.line}{logical; if \code{TRUE}, add a base line at \eqn{y =
      0}. Used when \code{plot.type} is \code{"line"}.}
  \item{points.plot}{logical; if \code{TRUE} original data are added to
    the plot.}
  \item{points.col, points.pch}{parameters used to draw the points.}
  \item{plot.type}{type of the plot.}
  \item{axes}{logical; if \code{TRUE} axis are drawn.}
  \item{ticks}{logical; if \code{TRUE} ticks are drawn.}
  \item{bins}{number of ticks to plot. }
  \item{shrink}{parameter that controls the size of the plotted circle.
  Default is 1.  Larger values shrink the circle, while smaller values
  enlarge the circle.}
\item{tcl}{length of the ticks.}
\item{tol}{proportion of white space at the margins of plot}
\item{uin}{desired values for the units per inch parameter. If of length
  1, the desired units per inch on the x axis.}
\item{xlim, ylim}{the ranges to be encompassed by the x and y
  axes. Useful for centering the plot.}
  \item{\dots}{futher parameters passed to \code{\link{plot.default}}.}
}

\value{
None.
}

\author{Claudio Agostinelli}

\seealso{\code{\link{density.circular}} and \code{\link{lines.density.circular}} }

\examples{
x <- rvonmises(n=100, mu=pi, kappa=2)
res25 <- density(x, bw=25)
plot(res25, points.plot=TRUE, xlim=c(-1.5,1))
res50 <- density(x, bw=25, adjust=2)
lines(res50, col=2)
}

\keyword{dplot}


\eof
\name{plot.edf}
\title{Plot Circular Empirical Distribution Function}
\alias{plot.edf}
\alias{lines.edf}

\description{
Plots the empirical distribution function of a circular data set. 
}

\usage{
\method{plot}{edf}(x, type = "s", xlim = c(0, 2 * pi), ylim = c(0, 1), \dots)
\method{lines}{edf}(x, type = "s", \dots)
}

\arguments{
  \item{x}{vector of circular data measured.}
  \item{type, xlim, ylim}{plotting parameters with useful defaults.}
\item{\dots}{optional graphical parameters.  See help section on \code{\link{par}}.}
}

\note{
Creates a plot or adds a plot (\code{lines.edf}) of the empirical
distribution function of the circular data vector.
}

\details{
The vector of data is taken modulo 2*pi, and then the linear ranks are used to generate an empirical distribution function.
}

\author{Claudio Agostinelli and Ulric Lund}

\seealso{
\code{\link{par}}
}

\examples{
# Compare the edf's of two simulated sets of data.
data1 <- rvonmises(n=10, mu=0, kappa=3)
data2 <- rvonmises(n=10, mu=0, kappa=1)
plot.edf(data1, xlab="Data", ylab="EDF", main="Plots of Two EDF's")
lines.edf(data2, lty=2, col=2)
}

\keyword{hplot}

\eof
\name{points.circular}
\title{Add Points to a Circular Plot}
\alias{points.circular}

\description{
Add points to a plot of circular data points on the current graphics device. 
}

\usage{
points.circular(x, pch = 16, cex = 1, stack = FALSE, sep = 0.025, shrink = 1, 
    bins, col, next.points, plot.info, zero, rotation, ...)
}

\arguments{
\item{x}{a vector, matrix or data.frame. The object is coerced to class \code{\link{circular}}.}
\item{pch}{point character to use.  See help on \code{\link{par}}.}
\item{cex}{point character size.  See help on par.}
\item{stack}{logical: if \code{TRUE}, points are stacked on the perimeter of the circle.  Otherwise, all points are plotted on the perimeter of the circle.  Default is \code{FALSE}.}
\item{sep}{constant used to specify the distance between stacked points,
  if \code{stack==TRUE} or in the case of more than one dataset.  Default is 0.025; smaller values will create smaller spaces.}
\item{shrink}{parameter that controls the size of the plotted circle.
  Default is 1.  Larger values shrink the circle, while smaller values
  enlarge the circle.}
\item{bins}{if \code{stack==TRUE}, bins is the number of arcs to partition the circle with.}
\item{col}{color of the points. The values are recycled if needed.}
\item{next.points}{if \code{stack=FALSE}, the distance from the circle
  the next dataset is plotted. This overrides the information in \code{plot.info}.}
\item{plot.info}{an object from \code{\link{plot.circular}} that
  contains information on the \code{zero}, the \code{rotation} and \code{next.points}.}
\item{zero}{the zero of the plot. This overrides the information in \code{plot.info}.}
\item{rotation}{the rotation of the plot. This overrides the information in \code{plot.info}.}
\item{...}{futher parameters passed to \code{\link{plot.default}}.}
}

\details{
When there are many closely distributed observations, stacking is
recommended. When stacking the points, if there are many points in a particular bin, it may be necessary to shrink the plot of the circle so that all points fit.  This is controlled with the parameter \code{shrink}.  Generally the parameter \code{sep} does not need adjustment, however, when shrinking the plot, or for a very large number of observations, it may be helpful.
}

\author{Claudio Agostinelli}

\seealso{
\code{\link{plot.circular}}.
}

\examples{
data.1 <- rvonmises(n=100, mu=0, kappa=3)
data.2 <- rvonmises(n=100, mu=pi/3, kappa=3) 
res <- plot(data.1, stack=FALSE, bins=150, shrink=1.5, col=1) 
points(data.2, plot.info=res, col=2)
}

\keyword{hplot}

\eof
\name{pp.plot}    
\title{von Mises Probability-Probability Plot}
\alias{pp.plot}

\description{
Plots the empirical distribution of a data set against the best fitting
von Mises distribution function.
}

\usage{
pp.plot(x, ref.line = TRUE, tol=1e-20,  xlab = "von Mises Distribution", ylab = "Empirical Distribution", ...)
}

\arguments{
\item{x}{a vector. The object is coerced to class \code{\link{circular}}.}
\item{ref.line}{logical, if TRUE a 45 degree reference line is added to
  the plot. Default is TRUE.}
\item{tol}{parameter passed to \code{\link{pvonmises}}.}
\item{xlab, ylab}{labels of the axis.}
\item{...}{parameters passed to the \code{\link{plot.default}} function.}
}

\value{
a list with the estimated mean and concentration parameter for a von
Mises distribution.
}


\details{
The maximum likelihood estimates of the parameters of the von Mises distribution are computed from the given data set.  The empirical distribution function is plotted against a von Mises distribution function with parameters given by the MLEs computed. 
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 10.2, World Scientific Press, Singapore.
}

\seealso{
\code{\link{mle.vonmises}}
}

\examples{
x <- rvonmises(n=25, mu=0, kappa=3)
pp.plot(x)
x <- c(rvonmises(n=20, mu=0, kappa=7), rvonmises(n=20, mu=pi, kappa=7))
pp.plot(x)
}

\keyword{hplot}

\eof
\name{rad}    
\title{Radians}
\alias{rad}

\description{
Converts degrees to radians. 
}

\usage{
rad(x)
}

\arguments{
\item{x}{vector or matrix of degree measurements.}
}

\value{
Returns a vector or matrix of radian measurements corresponding to the data in degrees.
}

\details{This function is available for compatibility with the CircStats
  package, please use \code{\link{conversion.circular}}.}

\author{Claudio Agostinelli and Ulric Lund}

\seealso{
\code{\link{conversion.circular}} and \code{\link{deg}}
}

\keyword{math}

\eof
\name{range.circular}
\title{Circular Range}
\alias{range.circular}

\description{
Computes the circular range of a data set and performs a test of uniformity if specified.
}

\usage{
range.circular(x, test=FALSE, na.rm = FALSE, finite = FALSE, ...)
}

\arguments{
\item{x}{a vector. The object is coerced to class \code{\link{circular}}.}
\item{test}{logical flag:  if TRUE then the test of uniformity is
  performed; otherwise the test is not performed.  Default is FALSE.}
\item{na.rm}{logical, indicating if \code{\link{NA}}'s should be omitted.}
\item{finite}{logical, indicating if all non-finite elements should be
  omitted.}
\item{\ldots}{further parameter passed from/to the method.}
}

\value{
Returns the circular range.  If the significance test is requested the p-value of the test is returned as p.value.
}

\details{
The circular range is the shortest arc on the circle containing the entire set of data.  The p-value is computed using the exact distribution of the circular range under the hypothesis of uniformity.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 7.4, World Scientific Press, Singapore.
}

\seealso{
\code{\link{kuiper.test}}, \code{\link{rao.spacing.test}},
\code{\link{rayleigh.test}} and \code{\link{watson.test}}.
}

\examples{
data <- rvonmises(n=50, mu=0, kappa=2)
range(data, test=TRUE)
data <- circular(runif(50, 0, 2*pi))
range(data, test=TRUE)
}

\keyword{univar}
\keyword{htest}

\eof
\name{rao.spacing.test}
\title{Rao's Spacing Test of Uniformity}
\alias{rao.spacing.test}
\alias{print.rao.spacing.test}

\description{
Performs Rao's spacing test of uniformity. 
}

\usage{
rao.spacing.test(x, alpha=0)
\method{print}{rao.spacing.test}(x, digits = 4, \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
  \item{alpha}{numeric value specifying the significance level of the
  test. The default value is 0, in which case, a range for the p-value
  will be returned.  Valid significance levels are 0.10, 0.05, 0.01 and
  0.001.}
\item{digits}{integer indicating the precision to be used.}
  \item{\dots}{further arguments passed to or from other methods.}
}

\value{
a list with the statistic, alpha and the number of observations.
}

\details{
If alpha is specified, critical values are determined from a table of simulated critical points (see reference below).  If alpha is not specified, a range for the p-value is determined using the table of simulated critical points.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 7.4, World Scientific Press, Singapore.

Rao, J.S. (1976). Some tests based on arc-lengths for the circle. Sankhya, The Indian Journal of Statistics, Serial B(4), 38, 329338.

Russell, G.S. and Levitin, D.J. (1995).  An expanded table of probability values for Rao's Spacing Test.  Communications in Statistics - Simulation and Computation, 24, 4, 879888.
}

\seealso{
\code{\link{range.circular}}, \code{\link{kuiper.test}}, \code{\link{rayleigh.test}} and \code{\link{watson.test}}
}

\keyword{htest}

\eof
\name{rao.table}
\title{Table for Rao's Spacing Test of Uniformity}
\alias{rao.table}

\description{Table for Rao's spacing test of uniformity}

\usage{data(rao.table)}

\author{Ulric Lund}

\seealso{
\code{\link{rao.spacing.test}}
}

\keyword{datasets}

\eof
\name{rao.test}
\title{Rao's Tests for Homogeneity}
\alias{rao.test}
\alias{print.rao.test}

\description{
Performs Rao's test for homogeneity on k populations of angular data. 
}

\usage{
rao.test(\dots, alpha=0)
\method{print}{rao.test}(x, digits = 4, \dots)
}

\arguments{
  \item{\dots}{a sequence of \code{\link{circular}} for the
	\code{rao.test} and further arguments passed to or from other
	methods for the \code{print.rao.test} function.}
  \item{alpha}{numeric value specifying the significance level of the
  test. Default is 0, in which case p-values for the test statistic is
  printed.}
  \item{x}{an object from the \code{rao.test}.}
  \item{digits}{integer indicating the precision to be used.}
}

\value{
A list with the statistic and p.value for the mean and the dispersion
and the value of alpha. 
}

\note{
The test is performed, and the results are written to the screen. Test results are given for both the test of equality of polar vectors, and of dispersions.  If alpha is specified, the test statistic is printed, along with the level critical value.  If alpha is not specified, a p-value for the test is printed.  
}

\details{
Critical values and p-values are determined according to the chi-squared approximation of the test statistic.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 7.6.1, World Scientific Press, Singapore.

Rao, J.S. (1967). Large sample tests for the homogeneity of angular data, Sankhya, Ser, B., 28.
}

\keyword{htest}

\eof
\name{rayleigh.test}
\title{Rayleigh Test of Uniformity}
\alias{rayleigh.test}
\alias{print.rayleigh.test}

\description{
Performs a Rayleigh test of uniformity, assessing the significance of
the mean resultant length.  The alternative hypothesis is a unimodal
distribution with unknown mean direction and unknown mean resultant
length if \code{mu} is missing otherwise the alternative hypothesis is a unimodal distribution with a specified mean direction and unknown mean resultant length.  
}

\usage{
rayleigh.test(x, mu)
\method{print}{rayleigh.test}(x, digits=4, \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
  \item{mu}{Specified mean direction in alternative hypothesis.}
    \item{digits}{integer indicating the precision to be used.}
	\item{\dots}{further arguments passed to or from other methods.}
  }

\value{
Returns a list with three components:  the mean resultant length, \code{statistic}, the p-value of the test statistic, \code{p.value} and
the value of the alternative mean direction \code{mu}.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Sections 3.3.2 and 3.4.1, World Scientific Press, Singapore.
}

\seealso{
\code{\link{range.circular}}, \code{\link{kuiper.test}},
\code{\link{rao.spacing.test}} and \code{\link{watson.test}}
}


\examples{
x <- rvonmises(n=25, mu=pi, kappa=2)
# General alternative
rayleigh.test(x)
# Specified alternative
rayleigh.test(x, mu=0)
}

\keyword{htest}

\eof
\name{rho.circular}
\title{Mean Resultant Length}
\alias{rho.circular}

\description{
Returns the mean resultant length of a vector of circular data. 
}

\usage{
rho.circular(x, na.rm = FALSE)
}

\arguments{
  \item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
  \item{na.rm}{logical, indicating if \code{\link{NA}}'s should be omitted.}
}


\value{
Returns the mean resultant length of data.
}

\details{
Each observation is treated as a unit vector, or point  on the unit circle.  The resultant vector of the observations is found, and the length of the resultant vector divided by the sample size is returned.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 1.3, World Scientific Press, Singapore.
}

\seealso{
\code{\link{mean.circular}}, \code{\link{var.circular}},
\code{\link{summary.circular}} and \code{\link{mle.vonmises}}.
}

\examples{
# Compute the mean resultant length of a random sample of observations.
data <- circular(runif(100, 0, 2*pi))
rho.circular(data)
}

\keyword{univar}

\eof
\name{rose.diag}
\title{Rose Diagram}
\alias{rose.diag}

\description{
Creates a rose diagram of a circular data set on the current graphics device.}

\usage{rose.diag(x, pch = 16, axes = TRUE, shrink = 1, bins, ticks = TRUE, tcl = 0.025, col, tol = 0.04,
uin, xlim = c(-1, 1), ylim = c(-1, 1), prop = 1, main = NULL, ...)
}

\arguments{

\item{x}{a vector, matrix or data.frame. The object is coerced to class \code{\link{circular}}.}
\item{pch}{point character to use.  See help on \code{\link{par}}.}
\item{axes}{logical: if \code{TRUE} axes are plotted according to properties of \code{x}.}
\item{shrink}{parameter that controls the size of the plotted circle.
  Default is 1.  Larger values shrink the circle, while smaller values
  enlarge the circle.}
\item{bins}{if \code{stack==TRUE}, bins is the number of arcs to partition the circle with.}
\item{ticks}{logical: if \code{TRUE} ticks are plotted according to the
  value of \code{bins}.}
\item{tcl}{length of the ticks.}
\item{col}{color of the points. The values are recycled if needed.}
\item{tol}{proportion of white space at the margins of plot.}
\item{uin}{desired values for the units per inch parameter. If of length
  1, the desired units per inch on the x axis.}
\item{xlim, ylim}{the ranges to be encompassed by the x and y
  axes. Useful for centering the plot.}
\item{prop}{numerical constant determining the radii of the sectors.  By default, prop = 1.}
\item{main}{title of the plot.}
\item{...}{futher parameters passed to \code{\link{plot.default}}.}
}

\value{
a list with information on the plot: zero, rotation and next.points.
}


\note{some codes from \code{\link{eqscplot}} in MASS is used.}

\details{
The circumference of the circle is split into groups, the number of groups specified by bins.  For each group, a sector is drawn.  The radii of the sectors are by default equal to the square root of the relative frequencies of observations in each group.  This ensures that the area of the sector is proportional to the group frequency.  The length of the radii can be controlled by varying the parameter prop. 
}

\author{Claudio Agostinelli and Ulric Lund}

\seealso{
\code{\link{plot.circular}}
}

\examples{
# Generate uniform data and create several rose diagrams.  
# Some optional parameters may be needed to optimize plots.
x <- circular(runif(50, 0, 2*pi))
rose.diag(x, bins = 18, main = 'Uniform Data')
points(x)
# Generate von Mises data and create several rose diagrams.
x <- rvonmises(n=25, mu=0, kappa=5, zero=pi/4)
y <- rose.diag(x, bins=18) # Points fall out of bounds.
points(x, plot.info=y, stack=TRUE)
y <- rose.diag(x, bins=36, prop=1.5, shrink=1.5) # Adjust optional parameters to fit all points on plot.
points(x, plot.info=y, stack=TRUE)
}

\keyword{hplot}

\eof
\name{rstable}
\title{Random Generation from the Stable Family of Distributions}
\alias{rstable}

\description{
Returns random deviates from the stable family of probability distributions.
}

\usage{
rstable(n, scale = 1, index = stop("no index arg"), skewness = 0)
}

\arguments{
\item{n}{sample size.}
\item{index}{number from the interval (0, 2]. An index of 2 corresponds to the normal, 1 to the Cauchy.  Smaller values mean longer tails.}
\item{skewness}{number giving the modified skewness (see Chambers et al., 1976).  Negative values correspond to skewness to the left (the median is smaller than the mean, if it exists), and positive values correspond to skewness to the right (the median is larger than the mean). The absolute value of skewness should not exceed 1.}
\item{scale}{the scale of the distribution.}
}

\value{
random sample from the specified stable distribution.
}

\details{
This function return random variates from the Levy skew stable
distribution with \code{index}=$\alpha$, \code{scale}=$c$ and \code{skewness}=$\beta$.  The \code{skewness} parameter must lie in the range [-1,1] while the \code{index} parameter must lie in the range (0,2].  The Levy skew stable probability distribution is defined by a fourier transform,
\eqn{
p(x) = {1 \over 2 \pi} \int_{-\infty}^{+\infty} dt \exp(-it x - |c t|^\alpha (1-i \beta sign(t) \tan(\pi\alpha/2)))
}

When $\alpha = 1$ the term $\tan(\pi \alpha/2)$ is replaced by $-(2/\pi)\log|t|$.   For $\alpha = 2$ the distribution reduces to a Gaussian distribution with $\sigma = \sqrt{2} scale$ and the skewness parameter has no effect.  
For $\alpha < 1$ the tails of the distribution become extremely
wide.  The symmetric distribution corresponds to $\beta =0$.

The Levy alpha-stable distributions have the property that if $N$
alpha-stable variates are drawn from the distribution $p(c, \alpha,
\beta)$ then the sum $Y = X_1 + X_2 + \dots + X_N$ will also be
distributed as an alpha-stable variate, $p(N^{1/\alpha} c, \alpha, \beta)$.

There is no explicit solution for the form of $p(x)$ and there are no density, probability or quantile functions supplied for this distribution.
}

\author{Claudio Agostinelli}

\references{
Chambers, J. M., Mallows, C. L. and Stuck, B. W. (1976). A Method for Simulating Stable Random Variables. Journal of the American Statistical Association 71, 340-344.

Lo\"{g}ae\"{v}e, M. (1977). Probability Theory I. (fourth edition) Springer-Verlag, New York.
}

\seealso{
\link{rnorm}, \link{rcauchy}.
}

\examples{
hist(rstable(200, 1.5, .5)) #fairly long tails, skewed right
}

\keyword{distribution}

\eof
\name{rwrappedstable}
\title{Random Generation from the Wrapped Stable Distribution}
\alias{rwrappedstable}

\description{
Generates pseudo-random numbers from a wrapped stable distribution.
}

\usage{
rwrappedstable(n, scale=1, index, skewness, units=c("radians", "degrees"), \dots)
}

\arguments{
  \item{n}{number of random numbers to generate.}
  \item{scale}{the scale of the distribution.}
\item{index}{number from the interval (0, 2]. An index of 2 corresponds to the normal, 1 to the Cauchy.  Smaller values mean longer tails.}
\item{skewness}{number giving the modified skewness. Negative values correspond to skewness to the left (the median is smaller than the mean, if it exists), and positive values correspond to skewness to the right (the median is larger than the mean). The absolute value of skewness should not exceed 1.}
\item{units}{units of measure desired.}
\item{\dots}{parameters passed to \code{\link{circular}}.}
}

\value{
Returns a vector of n independent random numbers generated from a wrapped stable distribution.
}

\details{
n random numbers are generated from a stable distribution with with parameters index, skewness and scale. The function returns these values modulo 2*pi.
}

\author{Claudio Agostinelli}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 2.2.8, World Scientific Press, Singapore.
}

\keyword{distribution}

\eof
\name{summary.circular}
\title{Circular Summary Statistics}
\alias{summary.circular}

\description{
Computes circular summary statistics including the sample size, mean direction and mean resultant length.
}

\usage{
summary.circular(object, ...)
}

\arguments{
  \item{object}{an object of class \code{\link{circular}}.}
  \item{...}{parameters passed to \code{\link{summary.matrix}} if needed.}
}

\value{
Returns a vector with the sample size, the sample mean direction and the sample mean resultant length.
}

\details{
Each observation is  treated  as  a  unit  vector or a point on the unit circle.  The resultant vector of the observations is found, and the direction of the resultant vector is returned as well as its length divided by the sample size.  
}

\author{Claudio Agostinelli and David Andel}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 1.3, World Scientific Press, Singapore.
}

\seealso{
\code{\link{mean.circular}}, \code{\link{var.circular}}, \code{\link{mle.vonmises}}, \code{\link{rho.circular}}.
}

\examples{
# Compute summary statistics of a random sample of observations. 
data <- circular(runif(50, 0, pi))
summary(data)
summary(data.frame(data, runif(50, 0, pi)))
}

\keyword{univar}

\eof
\name{ticks.circular}
\alias{ticks.circular}
\title{Draw Tick-Marks in a Circular Plot}
\description{
Draw tick-marks in a circular plot.
}
\usage{
ticks.circular(x, template = c("none", "geographics"), zero, rotation, tcl = 0.025, col, \dots)
}

\arguments{

  \item{x}{the points at which tick-marks are to be drawn.}
\item{template}{either \code{none} or \code{geographics}.}
\item{zero}{the zero of the plot (in radians).}
\item{rotation}{the rotation of the plot.}
\item{col}{color for the tick marks. If missing, function uses `par("col.axis")'. }
\item{tcl}{The length of tick marks.}
\item{\dots}{parameters passed to \code{line.default}.}
}

\author{Claudio Agostinelli}

\seealso{
  \code{\link{plot.circular}} and \code{\link{axis.circular}}
}

\keyword{hplot}

\eof
\name{triangular}    
\title{Triangular Density Function}
\alias{dtriangular}
\alias{rtriangular}

\description{
Density and random generation for the Triangular circular distribution. 
}

\usage{
dtriangular(x, rho)
rtriangular(n, rho, units=c("radians", "degrees"), \dots)
}

\arguments{
\item{x}{a vector. The object is coerced to class \code{\link{circular}}.}
\item{n}{number of observations.}  
\item{rho}{concentration parameter of the distribution.  rho must be
  between 0 and \eqn{4/pi^2}.}
\item{units}{units of measure desired.}
\item{\dots}{parameters passed to \code{\link{circular}}.}
}

\value{
\code{dtriangular} gives the density and \code{rtriangular} generates
random deviates.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 2.2.3, World Scientific Press, Singapore.
}

\keyword{distribution}

\eof
\name{trigonometric.moment}    
\title{Trigonometric Moments}
\alias{trigonometric.moment}  

\description{
Computes the specified order trigonometric moment for a set of directional data points. 
}

\usage{
trigonometric.moment(x, p=1, center=FALSE)
}

\arguments{
\item{x}{ }
\item{p}{order of trigonometric moment to be computed. Default is for a first order trigonometric moment.}
\item{center}{logical, whether to compute centered moments or not.  Default is to compute an uncentered moment.}
}

\value{
Returns a list with variables mu, rho, cos, sin, p, n, call,
respectively the pth trigonometric moment's direction, resultant length,
real and imaginary components, the order, the number of observations and
the call.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 1.3, World Scientific Press, Singapore.
}

\seealso{
\code{\link{var.circular}}, \code{\link{mean.circular}},
\code{\link{summary.circular}}, \code{\link{mle.vonmises}} and \code{\link{rho.circular}}
}

\keyword{math}

\eof
\name{var.circular}
\title{A measure of variance for Circular Data}
\alias{var.circular}

\description{
Returns one minus the mean resultant length divided by the sample size of a vector of circular data. 
}

\usage{
\method{var}{circular}(x, na.rm = FALSE, only.var = TRUE, \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
  \item{na.rm}{logical, indicating if \code{\link{NA}}'s should be
    omitted.}
  \item{only.var}{logical, if \code{FALSE} the mean result length is
    reported as well.}
  \item{\dots}{further arguments passed to or from other methods.}
}


\value{
Returns one minus the mean resultant length divided by the sample size of data if \code{only.var} is
\code{TRUE}, otherwise a vector with the following components: the number
of observations, the mean resultant length, the mean resultant length
divided by the sample size, and one minus the mean resultant length divided by the sample size.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 1.3, World Scientific Press, Singapore.
}

\seealso{
\code{\link{mean.circular}}, \code{\link{rho.circular}} and \code{\link{summary.circular}}.
}

\examples{
# Compute the mean resultant length of a random sample of observations.
x <- rvonmises(n=100, mu=0, kappa=1)
var(x)
}

\keyword{univar}

\eof
\name{var}
\title{Variance}
\alias{var}
\alias{var.default}
\alias{var.data.frame}

\description{
The \code{var} function from the \pkg{base} is replace by a new
\code{method} in order to report the variance of circular data
appropriatly. \code{var.default} is an alias of the original function
\code{\link[base]{var}}. The behavior would be the same for objects which are not
from \code{\link{class}} \code{\link{data.frame}} and
\code{\link{circular}} (in the last case the variance is define as one
minus the mean resultant length divided by the sample size of data, see
\code{\link{var.circular}} for more details). The method for
\code{data.frame} will apply the \code{var} function to each columns.
}

\usage{
var(x, \dots)
\method{var}{default}(x, y = NULL, na.rm = FALSE, use, \dots)
\method{var}{data.frame}(x, \dots)
}

\arguments{
  \item{x}{a numeric vector, matrix or data frame.}
  \item{y}{\code{NULL} (default) or a vector, matrix or data frame with
    compatible dimensions to \code{x}.  The default is equivalent to
    \code{y = x} (but more efficient).}
  \item{na.rm}{logical. Should missing values be removed?}
  \item{use}{an optional character string giving a
    method for computing covariances in the presence
    of missing values.  This must be (an abbreviation of) one of the strings
    \code{"all.obs"}, \code{"complete.obs"} or \code{"pairwise.complete.obs"}.}
  \item{\dots}{further arguments passed to or from other methods.}
}

\seealso{
\code{\link[base]{var}}, \code{\link{var.circular}}, \code{\link{rho.circular}} and \code{\link{summary.circular}}.
}

\keyword{univar}

\eof
\name{vonMises}
\title{von Mises Density Function}
\alias{dvonmises}
\alias{rvonmises}
\alias{pvonmises}

\description{
  Density, distribution function and random generation for the von Mises
  circular distribution.  
}

\usage{
dvonmises(x, mu, kappa)
pvonmises(q, mu, kappa, tol = 1e-20)
rvonmises(n, mu, kappa, units = c("radians", "degrees"), \dots)
}

\arguments{
  \item{x, q}{a vector. The object is coerced to class
    \code{\link{circular}}.}
\item{n}{number of observations.}  
\item{mu}{mean direction of the distribution.}
\item{kappa}{non-negative numeric value for the concentration parameter
  of the distribution.}
\item{units}{units of measure desired.}
\item{tol}{the precision in evaluating the distributon function.}
\item{\dots}{parameters passed to \code{\link{circular}}.}
}

\value{
\code{dvonmises} gives the density, \code{pvonmises} gives the
distribution function and \code{rvonmises} generates random deviates.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 2.2.4, World Scientific Press, Singapore.
}

\keyword{distribution}

\eof
\name{watson.test}
\title{Watson's Test }
\alias{watson.test}
\alias{print.watson.test}

\description{
Performs a Watson's goodness of fit test for the von Mises or circular uniform distribution. 
}

\usage{
watson.test(x, alpha=0, dist=c("uniform", "vonmises"))
\method{print}{watson.test}(x, digits = 4, \dots)
}

\arguments{
\item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
\item{alpha}{significance level of the test.  Valid levels are 0.01, 0.05, 0.1.  This argument may be ommited, in which case, a range for the p-value will be returned.}
\item{dist}{distribution to test for.  The default is the uniform
  distribution. To test for the von Mises distribution, set \code{dist}
  to "vonmises".}
  \item{digits}{integer indicating the precision to be used.}
  \item{\dots}{further arguments passed to or from other methods.}
}

\value{
a list with the statistic, alpha, the number of observations, the
distribution and 'row' which is used by \code{print.watson.test} to
evaluate the p-value.
}

\details{If \code{dist} = "uniform", Watson's one-sample test for the circular uniform distribution is performed, and the results are printed.  If alpha is specified and non-zero, the test statistic is printed along with the critical value and decision.  If alpha is omitted, the test statistic is printed and a range for the p-value of the test is given.

If \code{dist} = "vonmises", estimates of the population parameters are used to evaluate the von Mises distribution function at all data points, thereby arriving at a sample of approximately uniformly distributed data, if the original observations have a von Mises distribution. The one-sample Watson test is then applied to the transformed data as above.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 7.2, World Scientific Press, Singapore.

Stephens, M. (1970).  Use of the Kolmogorov-Smirnov, Cramer-von Mises and related statistics without extensive tables.  Journal of the Royal Statistical Society, B32, 115122.
}

\seealso{
\code{\link{range.circular}}, \code{\link{kuiper.test}}, \code{\link{rao.spacing.test}} and \code{\link{rayleigh.test}}
}

\examples{
# Generate data from the uniform distribution on the circle.
x <- circular(runif(100, 0, 2*pi))  
watson.test(x)
# Generate data from a von Mises distribution.
x <- rvonmises(n=50, mu=0, kappa=4) 
watson.test(x, alpha=0.05, dist="vonmises")
}

\keyword{htest}

\eof
\name{watson.two.test}
\title{Watson's Two-Sample Test of Homogeneity}
\alias{watson.two.test}
\alias{print.watson.two.test}

\description{
Performs Watson's test for homogeneity on two samples of circular data. 
}

\usage{
watson.two.test(x, y, alpha=0)
\method{print}{watson.two.test}(x, digits=4, \dots)
}

\arguments{
\item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
\item{y}{a vector. The object is coerced to class
    \code{\link{circular}}.}
\item{alpha}{significance level of the test.  Valid levels are 0.001, 0.01, 0.05, 0.1.  This argument may be ommited, in which case, a range for the p-value will be returned.}
  \item{digits}{integer indicating the precision to be used.}
  \item{\dots}{further arguments passed to or from other methods.}
}

\value{
a list with statistic, alpha and the number of observations of the first and 
second sample.
}

\details{
Watson's two-sample test of homogeneity is performed, and the results are printed.  If alpha is specified and non-zero, the test statistic is printed along with the critical value and decision.  If alpha is omitted, the test statistic is printed and a range for the p-value of the test is given.

Critical values for the test statistic are obtained using the asymptotic distribution of the test statistic.  It is recommended to use the obtained critical values and ranges for p-values only for combined sample sizes in excess of 17.  Tables are available for smaller sample sizes and can be found in Mardia (1972) for instance.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 7.5, World Scientific Press, Singapore.
}

\examples{
# Perform a two-sample test of homogeneity on two
# simulated data sets.
data1 <- rvonmises(n=20, mu=0, kappa=3)
data2 <- rvonmises(n=20, mu=pi, kappa=2)
watson.two.test(data1, data2, alpha=0.05)
watson.two.test(data1, data2)
}

\keyword{htest}

\eof
\name{wrappedCauchy}
\title{Wrapped Cauchy Density Function}
\alias{dwrappedcauchy}
\alias{rwrappedcauchy}

\description{
Density, and random generation for the wrapped Cauchy circular distribution.   
}

\usage{
dwrappedcauchy(x, mu = 0, rho = exp(-1))
rwrappedcauchy(n, mu = 0, rho = exp(-1), units = c("radians", "degrees"), \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
  \item{n}{number of observations.}  
  \item{mu}{mean direction of the distribution.}
  \item{rho}{concentration parameter of the distribution.  \code{rho}
    must be in the interval from 0 to 1.}
  \item{units}{units of measure desired.}
  \item{\dots}{parameters passed to \code{\link{circular}}.}

}

\value{
\code{dwrappedcauchy} gives the density and \code{rwrappedcauchy} generates random deviates.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 2.2.7, World Scientific Press, Singapore.
}

\keyword{distribution}

\eof
\name{wrappedNormal}
\title{Wrapped Normal Density Function}
\alias{dwrappednormal}
\alias{rwrappednormal}

\description{
Density, and random generation for the wrapped normal circular distribution.   
}

\usage{
dwrappednormal(x, mu = 0, rho, sd = 1, K, min.k = 10)
rwrappednormal(n, mu = 0, rho, sd = 1, units = c("radians", "degrees"), \dots)
}

\arguments{
  \item{x}{a vector. The object is coerced to class
    \code{\link{circular}}.}
  \item{n}{number of observations.}  

  \item{mu}{mean direction of the distribution.}
  \item{rho}{concentration parameter of the distribution.  \code{rho}
    must be in the interval from 0 to 1.}
  \item{sd}{standard deviation of the (unwrapped) normal distribution.}
  \item{K}{number of terms to be used in approximating the density.}
  \item{min.k}{minimum number of terms used in approximating the density.}
  \item{units}{units of measure desired.}
  \item{\dots}{parameters passed to \code{\link{circular}}.}
}

\value{
\code{dwrappednormal} gives the density and \code{rwrappednormal} generates random deviates.
}

\author{Claudio Agostinelli and Ulric Lund}

\references{
Jammalamadaka, S. Rao and SenGupta, A. (2001). Topics in Circular Statistics, Section 2.2.7, World Scientific Press, Singapore.
}

\keyword{distribution}

\eof
